PipeContext class abstract

Implemented types

Constructors

PipeContext()
const

Properties

annotationArgument → dynamic
The value passed as an argument to the annotation.
no setter
data → Data
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
meta → MetaScope
no setterinherited
nameOfParameter → String
The name of the parameter that corresponds to the pipe annotation.
no setter
reflect → Reflect
no setterinherited
request → Request
no setterinherited
response → Response
no setterinherited
route → RouteEntry
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → AnnotationType
Indicates whether argument is a body, query, param, or custom parameter
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited