RequestContext class abstract interface

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers → Headers
no setter
method → String
no setter
payloadResolver → PayloadResolver?
no setter
queryParameters → Map<String, dynamic>
no setter
queryParametersAll → Map<String, Iterable>
no setter
request → UnderlyingRequest
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segments → List<String>
no setter
uri → Uri
no setter

Methods

addCleanUp(void cleanUp()) → void
close() → Future<void>
Cleans up any resources used by the request
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
upgradeToWebSocket({Duration? ping}) → Future<WebSocket>

Operators

operator ==(Object other) → bool
The equality operator.
inherited