WebSocketContext class abstract interface

Implemented types

Properties

asyncSender → AsyncWebSocketSender
no setter
close → CloseWebSocket
no setter
data → Data
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
meta → MetaScope
no setterinherited
reflect → Reflect
no setterinherited
request → Request
no setterinherited
response → Response
no setterinherited
route → RouteEntry
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited