MemoryFile class

Constructors

MemoryFile(List<int> bytes, {required String mimeType, String? basename, String? extension})
const
MemoryFile.from(String content, {required String mimeType, String? basename, String? extension})
factory

Properties

basename → String?
final
bytes → List<int>
final
extension → String?
final
filename → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
mimeType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited