MetaScope class abstract interface

Implemented types

Properties

direct → Meta
no setter
hashCode → int
The hash code for this object.
no setterinherited
inherited → Meta
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add<T>(T instance) → void
Adds an instance to meta, which can be retrieved later.
inherited
get<T>() → List<T>?
inherited
has<T>() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited