Headers class abstract

Constructors

Headers()

Properties

acceptRanges ← String?
no getter
contentLength ↔ int?
getter/setter pair
contentRange ↔ (int, int, int)?
The range of bytes to be returned by the server.
getter/setter pair
contentType ↔ MediaType?
getter/setter pair
contentTypeString ← String?
no getter
cookies → Cookies
no setter
encoding ↔ Encoding
If Headers doesn't have a Content-Type header or it specifies an encoding that dart:convert doesn't support, this will be null.
getter/setter pair
exposed → Set<String>
no setter
filename ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ifModifiedSince ↔ DateTime?
If this is non-null and the requested resource hasn't been modified since this date and time, the server should return a 304 Not Modified response.
getter/setter pair
isEmpty → bool
no setter
isNotEmpty → bool
no setter
keys → Iterable<String>
no setter
lastModified ← DateTime?
no getter
length → int
no setter
mimeType ↔ String?
This is parsed from the Content-Type header in Headers. It contains only the MIME type, without any Content-Type parameters.
getter/setter pair
origin ↔ String?
getter/setter pair
range → (int, int?)?
The range of bytes requested by the client.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setCookies → SetCookies
no setter
transferEncoding ↔ String?
getter/setter pair
values → Map<String, List<String>>
no setter

Methods

add(String key, String value, {bool? expose}) → void
addAll(Map<String, String> headers) → void
addEverything(Map<String, Iterable<String>> headers) → void
clear() → void
expose(String key) → void
forEach(void f(String key, Iterable<String> value)) → void
get(String key) → String?
getAll(String key) → List<String>?
isExposed(String key) → bool
map<K2, V2>(MapEntry<K2, V2> convert(String key, Iterable<String> values)) → Map<K2, V2>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → void
Removed the header with case-insensitive name key.
set(String key, String value, {bool? expose}) → void
toString() → String
A string representation of this object.
inherited
unexpose(String key) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String value) → String?
operator []=(String key, String value) → void