Payload class abstract

Constructors

Payload()
const

Properties

contentLength → int?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() → Stream<List<int>>
readAsString({Encoding encoding = utf8}) → String
resolve(Headers headers) → Future<Body>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited