FullRequest class abstract

Implemented types
Implementers

Constructors

FullRequest()
const

Properties

body → Body
The body of the request, resolved from the original payload.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
headers → Headers
The headers of the request.
no setterinherited
ip → String?
The IP address of the client that sent the request.
no setterinherited
method → String
The HTTP method of the request.
no setterinherited
originalPayload → Payload
The original payload of the request.
no setterinherited
pathParameters → Map<String, String>
The path parameters of the request.
no setterinherited
payloadResolver → PayloadResolver?
no setterinherited
queryParameters → Map<String, dynamic>
The query parameters of the request.
no setterinherited
queryParametersAll → Map<String, Iterable>
The query parameters of the request, including multiple values for the same parameter, if any.
no setterinherited
request → UnderlyingRequest
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segments → List<String>
no setterinherited
uri → Uri
The URI of the request.
no setterinherited
wildcardParameters → Map<String, List<String>>
Captured wildcard path segments keyed by the wildcard name.
no setterinherited

Methods

addCleanUp(void cleanUp()) → void
inherited
close() → Future<void>
Cleans up any resources used by the request
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolvePayload() → Future<void>
Resolves the payload of the request for body to be accessible.
inherited
toString() → String
A string representation of this object.
inherited
upgradeToWebSocket({Duration? ping}) → Future<WebSocket>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited