Request class abstract

Implementers

Constructors

Request()
const

Properties

body → Body
The body of the request, resolved from the original payload.
no setter
hashCode → int
The hash code for this object.
no setterinherited
headers → Headers
The headers of the request.
no setter
ip → String?
The IP address of the client that sent the request.
no setter
method → String
The HTTP method of the request.
no setter
originalPayload → Payload
The original payload of the request.
no setter
pathParameters → Map<String, String>
The path parameters of the request.
no setter
queryParameters → Map<String, dynamic>
The query parameters of the request.
no setter
queryParametersAll → Map<String, Iterable>
The query parameters of the request, including multiple values for the same parameter, if any.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segments → Iterable<String>
The segments of the request path.
no setter
uri → Uri
The URI of the request.
no setter
wildcardParameters → Map<String, List<String>>
Captured wildcard path segments keyed by the wildcard name.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolvePayload() → Future<void>
Resolves the payload of the request for body to be accessible.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited