UnderlyingRequest class abstract

Constructors

UnderlyingRequest()
const

Properties

body → Payload
no setter
hashCode → int
The hash code for this object.
no setterinherited
headers → Headers
no setter
ip → String?
The IP address of the client that sent the request.
no setter
method → String
no setter
protocolVersion → String
The HTTP protocol version used in the request, either "1.0" or "1.1".
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
upgradeToWebSocket({Duration? ping}) → Future<WebSocket>

Operators

operator ==(Object other) → bool
The equality operator.
inherited