Response class abstract

Constructors

Response()
const

Properties

body ↔ Body
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Headers
getter/setter pair
joinedHeaders → Headers
The headers from the body, if any, joined with the headers from the response
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited