LifecycleComponents class abstract

Constructors

LifecycleComponents()
const

Properties

allowedOrigins → AllowOrigins?
no setter
catchers → List<ExceptionCatcher>
no setter
expectedHeaders → ExpectHeaders?
no setter
guards → List<Guard>
no setter
hashCode → int
The hash code for this object.
no setterinherited
interceptors → List<Interceptor>
no setter
middlewares → List<Middleware>
no setter
preventedHeaders → PreventHeaders?
no setter
requestWrappers → List<RequestWrapper>
no setter
responseHandler → ResponseHandler?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMeta({Meta? handler}) → Meta
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited